@@ -34,9 +34,9 @@ public:
     virtual ~GeneralPage();
     void fillUi();
 
-    void load();
-    void save();
-    virtual void defaults();
+    void load() Q_DECL_OVERRIDE;
+    void save() Q_DECL_OVERRIDE;
+    void defaults() Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void configureNotifications();
